<?php
/**
 * Brovy functions and definitions
 *
 * @package Brovy
 */

if ( ! function_exists( 'brovy_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function brovy_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on ZincyLite, use a find and replace
	 * to change 'brovy' to the name of your theme in all the template files
	 */
	load_child_theme_textdomain( 'brovy', get_stylesheet_directory() . '/languages' );

}
endif; // zincylite_setup
add_action( 'after_setup_theme', 'brovy_setup' );

function brovy_scripts() {
	
	wp_enqueue_style( 'zincylite-parent-style', get_template_directory_uri().'/style.css' );
	wp_enqueue_style( 'zincylite-style', get_stylesheet_uri(),array('zincylite-bx-slider-style') );
	wp_enqueue_style( 'zincylite-responsive', get_stylesheet_directory_uri().'/css/responsive.css' );
    if(is_rtl()){
        wp_enqueue_style( 'brovy-rtl', get_stylesheet_directory_uri().'/css/rtl.css' );
    }
}
add_action( 'wp_enqueue_scripts', 'brovy_scripts' );

add_action('wp_head' , 'brovy_dynamic_style',50);
function brovy_dynamic_style(){
    //top header bg_color
	$top_header_bgcolor = get_theme_mod( 'top_header_bgcolor' , '#f3f3f3' );
	$top_header_color = get_theme_mod( 'top_header_color' , '#828282' );
	//menu color
    $menu_bgpattern = get_theme_mod( 'menu_bgimage' , '');
    $menu_bgcolor = get_theme_mod( 'menu_bgcolor' , '#fff');
    $menu_color = get_theme_mod( 'menu_color' , '#989898' );
    ?>
    <style type="text/css">
      #top-header{
         <?php
         if(!empty($menu_bgpattern)){ 
            ?>
            background: rgba(0, 0, 0, 0) url("<?php echo esc_attr($menu_bgpattern); ?>") repeat scroll 0 0 ;
            <?php
        }
        else{
            ?>
            background: <?php echo esc_attr($menu_bgcolor);?>;
            <?php
        }?>
    }

    .top-right{
    background-color: transparent;    
    background: <?php echo esc_attr($top_header_bgcolor); ?>;    
}
.header-text span, .socials a, .search-box i.fa, .header-text{
color: <?php echo esc_attr($top_header_color); ?>;
}
.main-navigation li a{
color: <?php echo (esc_attr($menu_color)=="#fff")?"#989898":esc_attr($menu_color); ?>;    
}
</style>
<?php
}

if ( get_stylesheet() !== get_template() ) {
    add_filter( 'pre_update_option_theme_mods_' . get_stylesheet(), function ( $value, $old_value ) {
       update_option( 'theme_mods_' . get_template(), $value );
         return $old_value; // prevent update to child theme mods
     }, 10, 2 );
    add_filter( 'pre_option_theme_mods_' . get_stylesheet(), function ( $default ) {
        return get_option( 'theme_mods_' . get_template(), $default );
    } );
}

function zincy_lite_customizer_homepage_extend( $wp_customize ) {

    $wp_customize->add_setting(
        'feature_post_four',
        array(
            'default' => '',
            'sanitize_callback' => 'zincy_lite_sanitize_dropdown_general',
        )
    );

    if(class_exists('Zincy_Lite_Post_Dropdown')) {

        $wp_customize->add_control( new Zincy_Lite_Post_Dropdown( $wp_customize , 
            'feature_post_four',
            array(
                'label' => __( 'Service Post 4' , 'brovy' ),
                'section' => 'feature_post_section',
                'type' => 'select',
                'priority' => '65',
            )
        ) );
    }
    
    //icon
    $wp_customize->add_setting(
        'feature_post_four_icon',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'feature_post_four_icon',
        array(
            'section' => 'feature_post_section',
            'description' => __( 'Font Awesome icon name Example: fa-trophy' , 'brovy' ),
            'type' => 'text',
            'priority' => '65',
        )
    );     
}
add_action( 'customize_register', 'zincy_lite_customizer_homepage_extend' );